==> coupon-facade-1.0.3-20190806.080310-40-sources.jar: com/bizvane/couponfacade/models/vo/CouponUseVO.java <==
package com.bizvane.couponfacade.models.vo;

import java.io.Serializable;

/**
 * Created by yunjie.tian on 2018/12/5.
 */
public class CouponUseVO implements Serializable{

    private static final long serialVersionUID = 1L;

    @io.swagger.annotations.ApiModelProperty(value = "券号", name = "couponCode", required = false,example = "")
    private String couponCode;

    @io.swagger.annotations.ApiModelProperty(value = "品牌号", name = "sysBrandId", required = false,example = "")
    private Long brandId;

    @io.swagger.annotations.ApiModelProperty(value = "核销来源", name = "useFrom", required = false,example = "")
    private Byte useFrom;

    @io.swagger.annotations.ApiModelProperty(value = "员工编号", name = "staffCode", required = false,example = "")
    private String staffCode;
    
    
    @io.swagger.annotations.ApiModelProperty(value = "核销门店code", name = "核销门店code", required = false,example = "")
    private String verifyedStoreCode;
    
    @io.swagger.annotations.ApiModelProperty(value = "核销人(导购code)", name = "导购code", required = false,example = "")
    private String verifyedUser;
    
    

    public String getVerifyedStoreCode() {
		return verifyedStoreCode;
	}

	public void setVerifyedStoreCode(String verifyedStoreCode) {
		this.verifyedStoreCode = verifyedStoreCode;
	}

	public String getVerifyedUser() {
		return verifyedUser;
	}

	public void setVerifyedUser(String verifyedUser) {
		this.verifyedUser = verifyedUser;
	}

	public String getStaffCode() {
        return staffCode;
    }

    public void setStaffCode(String staffCode) {
        this.staffCode = staffCode;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Byte getUseFrom() {
        return useFrom;
    }

    public void setUseFrom(Byte useFrom) {
        this.useFrom = useFrom;
    }
}

==> coupon-facade-2.0.0-20200522.082834-94-sources.jar: com/bizvane/couponfacade/models/vo/CouponUseVO.java <==
package com.bizvane.couponfacade.models.vo;

import java.io.Serializable;

/**
 * Created by yunjie.tian on 2018/12/5.
 */
public class CouponUseVO implements Serializable{

    private static final long serialVersionUID = 1L;

	@io.swagger.annotations.ApiModelProperty(value = "公司id", name = "sysCompanyId", required = false,example = "")
    private Long sysCompanyId;

	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false,example = "")
	private Long brandId;

	@io.swagger.annotations.ApiModelProperty(value = "券号", name = "couponCode", required = false,example = "")
    private String couponCode;


    @io.swagger.annotations.ApiModelProperty(value = "核销来源", name = "useFrom", required = false,example = "")
    private Byte useFrom;

    @io.swagger.annotations.ApiModelProperty(value = "员工编号", name = "staffCode", required = false,example = "")
    private String staffCode;
    
    
    @io.swagger.annotations.ApiModelProperty(value = "核销门店code", name = "核销门店code", required = false,example = "")
    private String verifyedStoreCode;
    
    @io.swagger.annotations.ApiModelProperty(value = "核销人(导购code)", name = "导购code", required = false,example = "")
    private String verifyedUser;
    
    

    public String getVerifyedStoreCode() {
		return verifyedStoreCode;
	}

	public void setVerifyedStoreCode(String verifyedStoreCode) {
		this.verifyedStoreCode = verifyedStoreCode;
	}

	public String getVerifyedUser() {
		return verifyedUser;
	}

	public void setVerifyedUser(String verifyedUser) {
		this.verifyedUser = verifyedUser;
	}

	public String getStaffCode() {
        return staffCode;
    }

    public void setStaffCode(String staffCode) {
        this.staffCode = staffCode;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Byte getUseFrom() {
        return useFrom;
    }

    public void setUseFrom(Byte useFrom) {
        this.useFrom = useFrom;
    }

	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}
}
